==> cscec5b-wzxt-impl-3.0.0-20210624.112721-243-sources.jar: com/ejianc/business/wzxt/bean/PlanDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 使用计划实体明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_plan_detail")
public class PlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="plan_id")
    private java.lang.Long planId; // 主表主键ID
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="nums")
    private java.math.BigDecimal nums; // 需求数量
    @TableField(value="occupy_nums")
    private java.math.BigDecimal occupyNums; // 占用数量
    @TableField(value="surplus_nums")
    private java.math.BigDecimal surplusNums; // 剩余数量
    @TableField(value="control_num")
    private java.math.BigDecimal controlNum; // 总控数量
    @TableField(value="check_num")
    private java.math.BigDecimal checkNum; // 累计进场数量
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="material_source_id")
    private java.lang.String materialSourceId; // 物资来源主键
    @TableField(value="def1")
    private java.lang.String def1; // 自定义字段
    @TableField(value="def2")
    private java.lang.String def2; // 自定义字段
    @TableField(value="def3")
    private java.lang.String def3; // 自定义字段
    @TableField(value="def4")
    private java.lang.String def4; // 自定义字段
    @TableField(value="def5")
    private java.lang.String def5; // 自定义字段\
    @TableField(value="source_type")
    private java.lang.Integer sourceType; //

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public BigDecimal getControlNum() {
        return controlNum;
    }

    public void setControlNum(BigDecimal controlNum) {
        this.controlNum = controlNum;
    }

    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    /**
     * 主表主键ID
     */
    public java.lang.Long getPlanId() {
        return planId;
    }

    /**
     * 主表主键ID
     */
    public void setPlanId(java.lang.Long planId) {
        this.planId = planId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 需求数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 需求数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 占用数量
     */
    public java.math.BigDecimal getOccupyNums() {
        return occupyNums;
    }

    /**
     * 占用数量
     */
    public void setOccupyNums(java.math.BigDecimal occupyNums) {
        this.occupyNums = occupyNums;
    }
    /**
     * 剩余数量
     */
    public java.math.BigDecimal getSurplusNums() {
        return surplusNums;
    }

    /**
     * 剩余数量
     */
    public void setSurplusNums(java.math.BigDecimal surplusNums) {
        this.surplusNums = surplusNums;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    
}

==> cscec5b-wzxt-impl-3.0.0-20210908.113541-335-sources.jar: com/ejianc/business/wzxt/bean/PlanDetailEntity.java <==
package com.ejianc.business.wzxt.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 使用计划实体明细表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_wzxt_plan_detail")
public class PlanDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="plan_id")
    private java.lang.Long planId; // 主表主键ID
    @TableField(value="material_id")
    private java.lang.Long materialId; // 物资主键
    @TableField(value="material_name")
    private java.lang.String materialName; // 物资名称
    @TableField(value="material_type_id")
    private java.lang.Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 物料编码
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="nums")
    private java.math.BigDecimal nums; // 需求数量
    @TableField(value="occupy_nums")
    private java.math.BigDecimal occupyNums; // 占用数量
    @TableField(value="surplus_nums")
    private java.math.BigDecimal surplusNums; // 剩余数量
    @TableField(value="control_num")
    private java.math.BigDecimal controlNum; // 总控数量
    @TableField(value="check_num")
    private java.math.BigDecimal checkNum; // 累计进场数量
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="material_source_id")
    private java.lang.String materialSourceId; // 物资来源主键
    @TableField(value="def1")
    private java.lang.String def1; // 自定义字段
    @TableField(value="def2")
    private java.lang.String def2; // 自定义字段
    @TableField(value="def3")
    private java.lang.String def3; // 自定义字段
    @TableField(value="def4")
    private java.lang.String def4; // 自定义字段
    @TableField(value="def5")
    private java.lang.String def5; // 自定义字段\
    @TableField(value="source_type")
    private java.lang.Integer sourceType; //
    @TableField(value="width")
    private java.lang.String width; // 宽度
    @TableField(value="height")
    private java.lang.String height; // 高度
    @TableField(value="length")
    private java.lang.String length; // 长度
    @TableField(value="surface")
    private java.lang.String surface; // 表面处理
    @TableField(value="color")
    private java.lang.String color; // 颜色
    @TableField(value="color_number")
    private java.lang.String colorNumber; // 色号
    @TableField(value="texture_material")
    private java.lang.String textureMaterial; // 材质状态
    @TableField(value="wall_thickness")
    private java.lang.String wallThickness; // 壁厚要求
    @TableField(value="building_number")
    private java.lang.String buildingNumber; // 栋号

    public String getWidth() {
        return width;
    }

    public void setWidth(String width) {
        this.width = width;
    }

    public String getHeight() {
        return height;
    }

    public void setHeight(String height) {
        this.height = height;
    }

    public String getLength() {
        return length;
    }

    public void setLength(String length) {
        this.length = length;
    }

    public String getSurface() {
        return surface;
    }

    public void setSurface(String surface) {
        this.surface = surface;
    }

    public String getColor() {
        return color;
    }

    public void setColor(String color) {
        this.color = color;
    }

    public String getColorNumber() {
        return colorNumber;
    }

    public void setColorNumber(String colorNumber) {
        this.colorNumber = colorNumber;
    }

    public String getTextureMaterial() {
        return textureMaterial;
    }

    public void setTextureMaterial(String textureMaterial) {
        this.textureMaterial = textureMaterial;
    }

    public String getWallThickness() {
        return wallThickness;
    }

    public void setWallThickness(String wallThickness) {
        this.wallThickness = wallThickness;
    }

    public String getBuildingNumber() {
        return buildingNumber;
    }

    public void setBuildingNumber(String buildingNumber) {
        this.buildingNumber = buildingNumber;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public BigDecimal getControlNum() {
        return controlNum;
    }

    public void setControlNum(BigDecimal controlNum) {
        this.controlNum = controlNum;
    }

    public BigDecimal getCheckNum() {
        return checkNum;
    }

    public void setCheckNum(BigDecimal checkNum) {
        this.checkNum = checkNum;
    }

    public String getDef1() {
        return def1;
    }

    public void setDef1(String def1) {
        this.def1 = def1;
    }

    public String getDef2() {
        return def2;
    }

    public void setDef2(String def2) {
        this.def2 = def2;
    }

    public String getDef3() {
        return def3;
    }

    public void setDef3(String def3) {
        this.def3 = def3;
    }

    public String getDef4() {
        return def4;
    }

    public void setDef4(String def4) {
        this.def4 = def4;
    }

    public String getDef5() {
        return def5;
    }

    public void setDef5(String def5) {
        this.def5 = def5;
    }

    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }

    /**
     * 主表主键ID
     */
    public java.lang.Long getPlanId() {
        return planId;
    }

    /**
     * 主表主键ID
     */
    public void setPlanId(java.lang.Long planId) {
        this.planId = planId;
    }
    /**
     * 物资主键
     */
    public java.lang.Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资主键
     */
    public void setMaterialId(java.lang.Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资类别
     */
    public java.lang.Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资类别
     */
    public void setMaterialTypeId(java.lang.Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资类别名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资类别名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 需求数量
     */
    public java.math.BigDecimal getNums() {
        return nums;
    }

    /**
     * 需求数量
     */
    public void setNums(java.math.BigDecimal nums) {
        this.nums = nums;
    }
    /**
     * 占用数量
     */
    public java.math.BigDecimal getOccupyNums() {
        return occupyNums;
    }

    /**
     * 占用数量
     */
    public void setOccupyNums(java.math.BigDecimal occupyNums) {
        this.occupyNums = occupyNums;
    }
    /**
     * 剩余数量
     */
    public java.math.BigDecimal getSurplusNums() {
        return surplusNums;
    }

    /**
     * 剩余数量
     */
    public void setSurplusNums(java.math.BigDecimal surplusNums) {
        this.surplusNums = surplusNums;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    
}
